@@ -3,12 +3,12 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0004';
+our $VERSION = '0.0005';
 
 use Moo;
 use strictures 2;
 use Carp qw(croak);
-use Mojo::JSON qw(to_json);
+use Mojo::JSON qw(from_json to_json);
 use Mojo::SQLite ();
 use namespace::clean;
 
@@ -79,7 +79,6 @@ sub make_setting {
     $id = $self->_sqlite->insert(
       $self->model,
       {
-        id       => $id,
         name     => $name,
         settings => to_json(\%args),
       },
@@ -92,18 +91,30 @@ sub make_setting {
 sub recall_setting {
   my ($self, %args) = @_;
   my $id = delete $args{id};
-  my $name = delete $args{name};
   croak 'No id given' unless $id;
   my $setting = $self->_sqlite->select(
     $self->model,
     ['settings'],
-    {
-      id => $id,
-    },
+    { id => $id },
   )->expand(json => 'settings')->hash;
   return $setting;
 }
 
+
+sub recall_settings {
+  my ($self, %args) = @_;
+  my $name = delete $args{name};
+  croak 'No name given' unless $name;
+  my $results = $self->_sqlite->query(
+    'select id,settings from ' . $self->model . " where name='$name'"
+  );
+  my @settings;
+  while (my $next = $results->hash) {
+    push @settings, { $next->{id} => from_json($next->{settings}) };
+  }
+  return \@settings;
+}
+
 1;
 
 __END__
@@ -118,7 +129,7 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0004
+version 0.0005
 
 =head1 SYNOPSIS
 
@@ -126,10 +137,10 @@ version 0.0004
 
   my $synth = Synth::Config->new(model => 'Moog Matriarch');
 
-  my $id = $synth->make_setting(foo => 'bar', etc => '...');
+  my $id = $synth->make_setting(name => 'Foo!', etc => '...');
 
   my $setting = $synth->recall_setting(id => $id);
-  # { foo => 'bar', etc => '...' }
+  # { name => 'Foo!', etc => '...' }
 
   #my $result = $synth->render_setting(...); # TODO
 
@@ -184,8 +195,10 @@ given B<model>.
 
   my $id = $synth->make_setting(%args);
 
-Save a named setting with a db "update or insert" operation and return
-the record id.
+Save a named setting and return the record id.
+
+The B<name> is required. If an B<id> is given, an update is performed.
+Otherwise, a database insert is made.
 
 Example:
 
@@ -200,6 +213,12 @@ Example:
 
 Return the parameters of a setting for the given B<id>.
 
+=head2 recall_settings
+
+  my $settings = $synth->recall_settings(name => $name);
+
+Return all the settings for a given B<name>.
+
 =head1 SEE ALSO
 
 L<Moo>
